<?php
// 05-06-2020 PJC v1.01 Unset $ent
// PJC v1.00

include "tzone.php"; // include timezone
$ds = ldap_connect("127.0.0.1",4000);
if ( ! $ds) {
	echo "LDAP connect failure<br>";
} else {
	$r = ldap_bind($ds,"INTERNAL","0123456");
	if ( ! $r) {
		echo "LDAP bind failure<br>";
		$ds = false;
	}
}

if (isset($_REQUEST['backup']) && $_REQUEST['backup']==="on") {
	$backup = "Backup ".date('d.m.y His')." - PreSSLUpdateTime.txt";
	$ent["dobackupto"][0] = $backup;
	ldap_modify($ds,"cn=Commands", $ent);
	ldap_modify($ds,"cn=Commands", $ent); $ent='';
}

$phones = (isset($_REQUEST['phones']) && count($_REQUEST['phones']) >0 ) ? $_REQUEST['phones'] : NULL;
$stun = (isset($_REQUEST['stun']) && strlen($_REQUEST['stun']) >0 ) ? $_REQUEST['stun'] : NULL;
$stunport = (isset($_REQUEST['stunport']) && strlen($_REQUEST['stunport']) >0 ) ? $_REQUEST['stunport'] : NULL;
$stunmode = (isset($_REQUEST['stunmode']) && strlen($_REQUEST['stunmode']) >0 ) ? $_REQUEST['stunmode'] : NULL;

if ($phones) {
unset($ent);
	foreach ($phones as $k => $guid) {
		$dn = "cn=1,guid=$guid";
		$ent["stunaddr"][0] = $stun;    
		$ent["stunport"][0] = $stunport;    
		if ($stunmode != NULL) {
			$ent["usestun"][0] = $stunmode;    
		}
		ldap_modify($ds, $dn, $ent); unset ($ent);
	}
}
	
?>